==> octave-2.9.14.tar.gz: octave-2.9.14/liboctave/MArray-i.cc <==
/*

Copyright (C) 1996, 1997 John W. Eaton

This file is part of Octave.

Octave is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 2, or (at your option) any
later version.

Octave is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License
along with Octave; see the file COPYING.  If not, write to the Free
Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301, USA.

*/

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "oct-inttypes.h"

// Instantiate MArrays of int values.

#include "MArray.h"
#include "MArray.cc"

template class OCTAVE_API MArray<int>;
template class OCTAVE_API MArray<long>;

INSTANTIATE_MARRAY_FRIENDS (int, OCTAVE_API)
INSTANTIATE_MARRAY_FRIENDS (long, OCTAVE_API)

template class OCTAVE_API MArray<octave_int8>;
template class OCTAVE_API MArray<octave_int16>;
template class OCTAVE_API MArray<octave_int32>;
template class OCTAVE_API MArray<octave_int64>;

INSTANTIATE_MARRAY_FRIENDS (octave_int8, OCTAVE_API)
INSTANTIATE_MARRAY_FRIENDS (octave_int16, OCTAVE_API)
INSTANTIATE_MARRAY_FRIENDS (octave_int32, OCTAVE_API)
INSTANTIATE_MARRAY_FRIENDS (octave_int64, OCTAVE_API)

template class OCTAVE_API MArray<octave_uint8>;
template class OCTAVE_API MArray<octave_uint16>;
template class OCTAVE_API MArray<octave_uint32>;
template class OCTAVE_API MArray<octave_uint64>;

INSTANTIATE_MARRAY_FRIENDS (octave_uint8, OCTAVE_API)
INSTANTIATE_MARRAY_FRIENDS (octave_uint16, OCTAVE_API)
INSTANTIATE_MARRAY_FRIENDS (octave_uint32, OCTAVE_API)
INSTANTIATE_MARRAY_FRIENDS (octave_uint64, OCTAVE_API)

#include "MArray2.h"
#include "MArray2.cc"

template class OCTAVE_API MArray2<int>;

INSTANTIATE_MARRAY2_FRIENDS (int, OCTAVE_API)

#include "MArrayN.h"
#include "MArrayN.cc"

template class OCTAVE_API MArrayN<int>;

INSTANTIATE_MARRAYN_FRIENDS (int, OCTAVE_API)

template class OCTAVE_API MArrayN<octave_int8>;
template class OCTAVE_API MArrayN<octave_int16>;
template class OCTAVE_API MArrayN<octave_int32>;
template class OCTAVE_API MArrayN<octave_int64>;

INSTANTIATE_MARRAYN_FRIENDS (octave_int8, OCTAVE_API)
INSTANTIATE_MARRAYN_FRIENDS (octave_int16, OCTAVE_API)
INSTANTIATE_MARRAYN_FRIENDS (octave_int32, OCTAVE_API)
INSTANTIATE_MARRAYN_FRIENDS (octave_int64, OCTAVE_API)

template class OCTAVE_API MArrayN<octave_uint8>;
template class OCTAVE_API MArrayN<octave_uint16>;
template class OCTAVE_API MArrayN<octave_uint32>;
template class OCTAVE_API MArrayN<octave_uint64>;

INSTANTIATE_MARRAYN_FRIENDS (octave_uint8, OCTAVE_API)
INSTANTIATE_MARRAYN_FRIENDS (octave_uint16, OCTAVE_API)
INSTANTIATE_MARRAYN_FRIENDS (octave_uint32, OCTAVE_API)
INSTANTIATE_MARRAYN_FRIENDS (octave_uint64, OCTAVE_API)

#include "MDiagArray2.h"
#include "MDiagArray2.cc"

template class OCTAVE_API MDiagArray2<int>;

INSTANTIATE_MDIAGARRAY2_FRIENDS (int, OCTAVE_API)

/*
;;; Local Variables: ***
;;; mode: C++ ***
;;; End: ***
*/

==> octave-3.5.90.tar.gz: octave-3.5.90/liboctave/MArray-i.cc <==
/*

Copyright (C) 1995-2011 John W. Eaton

This file is part of Octave.

Octave is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 3 of the License, or (at your
option) any later version.

Octave is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License
along with Octave; see the file COPYING.  If not, see
<http://www.gnu.org/licenses/>.

*/

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "oct-inttypes.h"

// Instantiate MArrays of int values.

#include "MArray.h"
#include "MArray.cc"

template class OCTAVE_API MArray<int>;
template class OCTAVE_API MArray<long>;

// Explicit instantiation, as this seems to be required by weird compilers
// like MSVC. This should be harmless on other compilers.
template int xmin<int> (int, int);
template int xmax<int> (int, int);
template long xmin<long> (long, long);
template long xmax<long> (long, long);

INSTANTIATE_MARRAY_FRIENDS (int, OCTAVE_API)
INSTANTIATE_MARRAY_FRIENDS (long, OCTAVE_API)

template class OCTAVE_API MArray<octave_int8>;
template class OCTAVE_API MArray<octave_int16>;
template class OCTAVE_API MArray<octave_int32>;
template class OCTAVE_API MArray<octave_int64>;

INSTANTIATE_MARRAY_FRIENDS (octave_int8, OCTAVE_API)
INSTANTIATE_MARRAY_FRIENDS (octave_int16, OCTAVE_API)
INSTANTIATE_MARRAY_FRIENDS (octave_int32, OCTAVE_API)
INSTANTIATE_MARRAY_FRIENDS (octave_int64, OCTAVE_API)

template class OCTAVE_API MArray<octave_uint8>;
template class OCTAVE_API MArray<octave_uint16>;
template class OCTAVE_API MArray<octave_uint32>;
template class OCTAVE_API MArray<octave_uint64>;

INSTANTIATE_MARRAY_FRIENDS (octave_uint8, OCTAVE_API)
INSTANTIATE_MARRAY_FRIENDS (octave_uint16, OCTAVE_API)
INSTANTIATE_MARRAY_FRIENDS (octave_uint32, OCTAVE_API)
INSTANTIATE_MARRAY_FRIENDS (octave_uint64, OCTAVE_API)

#include "MDiagArray2.h"
#include "MDiagArray2.cc"

template class OCTAVE_API MDiagArray2<int>;

INSTANTIATE_MDIAGARRAY2_FRIENDS (int, OCTAVE_API)
